package solutions.bitbadger.documents.integration.sqlite

import solutions.bitbadger.documents.*
import solutions.bitbadger.documents.integration.TEST_TABLE
import solutions.bitbadger.documents.integration.ThrowawayDatabase
import java.io.File

/**
 * A wrapper for a throwaway SQLite database
 */
class SQLiteDB : ThrowawayDatabase {

    private var dbName = ""

    init {
        dbName = "test-db-${AutoId.generateRandomString(8)}.db"
        Configuration.connectionString = "jdbc:sqlite:$dbName"
    }

    override val conn = Configuration.dbConn()

    init {
        conn.ensureTable(TEST_TABLE)
    }

    override fun close() {
        conn.close()
        File(dbName).delete()
    }

    override fun dbObjectExists(name: String) =
        conn.customScalar("SELECT EXISTS (SELECT 1 FROM sqlite_master WHERE name = :name) AS it",
            listOf(Parameter(":name", ParameterType.STRING, name)), Results::toExists)
}
